package com.ruoyi.mall.service;

import com.ruoyi.mall.domain.MallSchoolLevel;

import java.util.List;

/**
 * 学校办学层次Service接口
 *
 * @author Lsm
 * @date 2023-10-18
 */
public interface IMallSchoolLevelService
{
    /**
     * 查询学校办学层次
     *
     * @param schoolLevelId 学校办学层次主键
     * @return 学校办学层次
     */
    public MallSchoolLevel selectMallSchoolLevelBySchoolLevelId(Long schoolLevelId);

    /**
     * 查询学校办学层次列表
     *
     * @param mallSchoolLevel 学校办学层次
     * @return 学校办学层次集合
     */
    public List<MallSchoolLevel> selectMallSchoolLevelList(MallSchoolLevel mallSchoolLevel);

    /**
     * 新增学校办学层次
     *
     * @param mallSchoolLevel 学校办学层次
     * @return 结果
     */
    public int insertMallSchoolLevel(MallSchoolLevel mallSchoolLevel);

    /**
     * 修改学校办学层次
     *
     * @param mallSchoolLevel 学校办学层次
     * @return 结果
     */
    public int updateMallSchoolLevel(MallSchoolLevel mallSchoolLevel);

    /**
     * 批量删除学校办学层次
     *
     * @param schoolLevelIds 需要删除的学校办学层次主键集合
     * @return 结果
     */
    public int deleteMallSchoolLevelBySchoolLevelIds(Long[] schoolLevelIds);

    /**
     * 删除学校办学层次信息
     *
     * @param schoolLevelId 学校办学层次主键
     * @return 结果
     */
    public int deleteMallSchoolLevelBySchoolLevelId(Long schoolLevelId);
}
